<?php

namespace Litecms\WithdrawSettings\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\WithdrawSettings\Http\Requests\WithdrawSettingsRequest;
use Litecms\WithdrawSettings\Interfaces\WithdrawSettingsRepositoryInterface;
use Litecms\WithdrawSettings\Models\WithdrawSettings;

/**
 * Resource controller class for withdraw_settings.
 */
class WithdrawSettingsResourceController extends BaseController
{

    /**
     * Initialize withdraw_settings resource controller.
     *
     * @param type WithdrawSettingsRepositoryInterface $withdraw_settings
     *
     * @return null
     */
    public function __construct(WithdrawSettingsRepositoryInterface $withdraw_settings)
    {
        parent::__construct();
        $this->repository = $withdraw_settings;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\WithdrawSettings\Repositories\Criteria\WithdrawSettingsResourceCriteria::class);
    }

    /**
     * Display a list of withdraw_settings.
     *
     * @return Response
     */
    public function index(WithdrawSettingsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\WithdrawSettings\Repositories\Presenter\WithdrawSettingsPresenter::class)
                ->$function();
        }

        $withdraw_settings = $this->repository->paginate();

        return $this->response->title(trans('withdraw_settings::withdraw_settings.names'))
            ->view('withdraw_settings::withdraw_settings.index', true)
            ->data(compact('withdraw_settings'))
            ->output();
    }

    /**
     * Display withdraw_settings.
     *
     * @param Request $request
     * @param Model   $withdraw_settings
     *
     * @return Response
     */
    public function show(WithdrawSettingsRequest $request, WithdrawSettings $withdraw_settings)
    {

        if ($withdraw_settings->exists) {
            $view = 'withdraw_settings::withdraw_settings.show';
        } else {
            $view = 'withdraw_settings::withdraw_settings.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('withdraw_settings::withdraw_settings.name'))
            ->data(compact('withdraw_settings'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new withdraw_settings.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(WithdrawSettingsRequest $request)
    {

        $withdraw_settings = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('withdraw_settings::withdraw_settings.name')) 
            ->view('withdraw_settings::withdraw_settings.create', true) 
            ->data(compact('withdraw_settings'))
            ->output();
    }

    /**
     * Create new withdraw_settings.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(WithdrawSettingsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $withdraw_settings                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('withdraw_settings::withdraw_settings.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('withdraw_settings/withdraw_settings/' . $withdraw_settings->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/withdraw_settings/withdraw_settings'))
                ->redirect();
        }

    }

    /**
     * Show withdraw_settings for editing.
     *
     * @param Request $request
     * @param Model   $withdraw_settings
     *
     * @return Response
     */
    public function edit(WithdrawSettingsRequest $request, WithdrawSettings $withdraw_settings)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('withdraw_settings::withdraw_settings.name'))
            ->view('withdraw_settings::withdraw_settings.edit', true)
            ->data(compact('withdraw_settings'))
            ->output();
    }

    /**
     * Update the withdraw_settings.
     *
     * @param Request $request
     * @param Model   $withdraw_settings
     *
     * @return Response
     */
    public function update(WithdrawSettingsRequest $request, WithdrawSettings $withdraw_settings)
    {
        try {
            $attributes = $request->all();

            $withdraw_settings->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('withdraw_settings::withdraw_settings.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('withdraw_settings/withdraw_settings/' . $withdraw_settings->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('withdraw_settings/withdraw_settings/' . $withdraw_settings->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the withdraw_settings.
     *
     * @param Model   $withdraw_settings
     *
     * @return Response
     */
    public function destroy(WithdrawSettingsRequest $request, WithdrawSettings $withdraw_settings)
    {
        try {

            $withdraw_settings->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('withdraw_settings::withdraw_settings.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('withdraw_settings/withdraw_settings/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('withdraw_settings/withdraw_settings/' . $withdraw_settings->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple withdraw_settings.
     *
     * @param Model   $withdraw_settings
     *
     * @return Response
     */
    public function delete(WithdrawSettingsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('withdraw_settings::withdraw_settings.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('withdraw_settings/withdraw_settings'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/withdraw_settings/withdraw_settings'))
                ->redirect();
        }

    }

    /**
     * Restore deleted withdraw_settings.
     *
     * @param Model   $withdraw_settings
     *
     * @return Response
     */
    public function restore(WithdrawSettingsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('withdraw_settings::withdraw_settings.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/withdraw_settings/withdraw_settings'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/withdraw_settings/withdraw_settings/'))
                ->redirect();
        }

    }

}
